from .eatlocal import extract_bite, submit_bite, download_bite
from .cli import get_args
import os

USERNAME = os.environ.get("PYBITES_USERNAME")
PASSWORD = os.environ.get("PYBITES_PASSWORD")


def main():
    args = get_args()
    if args.extract:
        extract_bite(args.extract)
    elif args.submit:
        submit_bite(args.submit)
    elif args.download:
        download_bite(args.download, USERNAME, PASSWORD)


if __name__ == "__main__":
    main()



from selenium import webdriver
from selenium.webdriver.chrome.options import Options
from selenium.webdriver.common.by import By
from selenium.webdriver.common.keys import Keys
from time import sleep
from zipfile import ZipFile
import subprocess
import webbrowser


def download_bite(bite_number, username, password):
    """Download bite .zip from the platform.

    :bite_number: The number of the bite you want to download.
    :returns: None
    """

    options = Options()
    options.add_argument("--headless")
    options.add_argument("window-size=1920x1080")
    driver = webdriver.Chrome(options=options)

    login_url = "https://codechalleng.es/login"

    print("Logging into PyBites")
    driver.get(login_url)
    username_field = driver.find_element(By.ID, "id_username")
    username_field.send_keys(username)
    password_field = driver.find_element(By.ID, "id_password")
    password_field.send_keys(password)
    password_field.send_keys(Keys.RETURN)

    print(f"Retrieving bite {bite_number}")
    sleep(2)
    bite_url = f"https://codechalleng.es/bites/api/downloads/bites/{bite_number}"
    driver.get(bite_url)
    sleep(2)
    print(f"Bite {bite_number} successully downloaded to current directory")
    extract_bite(bite_number)


def extract_bite(bite_number):
    """Extracts all the required files into a new directory
    named by the bite number.

    :bite_number: The number of the bite you want to extract.
    :returns: None
    """

    bite = f"pybites_bite{bite_number}.zip"

    try:
        with ZipFile(bite, "r") as zfile:
            zfile.extractall(f"./{bite_number}")

        print(f"Extracted bite {bite_number}")
        subprocess.call(["rm", bite])

    except FileNotFoundError:
        print("No bite found.")


def submit_bite(bite_number):
    """Submits bite by pushing to git hub and opening
    webbrowser to the bit page.

    :bite_number: The number of the bite you want to submit.
    :returns: None
    """

    subprocess.call(
        ["git", "add", "."],
        stdout=subprocess.DEVNULL,
        stderr=subprocess.STDOUT,
    )
    subprocess.call(
        ["git", "commit", f"-m'submission Bite {bite_number} @ codechalleng.es'"],
        stdout=subprocess.DEVNULL,
        stderr=subprocess.STDOUT,
    )
    subprocess.call(
        ["git", "push"],
        stdout=subprocess.DEVNULL,
        stderr=subprocess.STDOUT,
    )

    print(f"\nPushed bite {bite_number} to github")

    url = f"https://codechalleng.es/bites/{bite_number}/"
    webbrowser.open(url)



import argparse
from . import __version__ as version


def get_args():
    parser = argparse.ArgumentParser(
        description="Download, extract, and submit PyBites",
        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
    )
    parser.add_argument(
        "-v", "--version", action="version", version=f"%(prog)s {version}"
    )

    group = parser.add_mutually_exclusive_group(required=True)
    group.add_argument(
        "-d",
        "--download",
        help="Download bite",
        dest="download",
    )
    group.add_argument(
        "-e",
        "--extract",
        help="Extract files into appropriate directory",
        dest="extract",
    )
    group.add_argument(
        "-s",
        "--submit",
        help="Submit bite",
        dest="submit",
    )

    return parser.parse_args()
